Index: /issm/trunk-jpl/src/m/classes/SMBgemb.m
===================================================================
--- /issm/trunk-jpl/src/m/classes/SMBgemb.m	(revision 28065)
+++ /issm/trunk-jpl/src/m/classes/SMBgemb.m	(revision 28066)
@@ -98,5 +98,5 @@
 		dzMin = NaN; % initial min vertical allowable grid spacing (default dzMin/2) [m]
 
-		zY    = NaN; % strech grid cells bellow top_z by a [top_dz * y ^ (cells bellow top_z)]
+		zY    = NaN; % stretch grid cells bellow top_z by a [top_dz * y ^ (cells bellow top_z)]
 		zMax = NaN; %initial max model depth (default is min(thickness,250)) [m]
 		zMin = NaN; %initial min model depth (default is min(thickness,130)) [m]
@@ -186,5 +186,5 @@
 			fielddisplay(self,'zMax','initial max model depth (default is min(thickness,250)) [m]');
 			fielddisplay(self,'zMin','initial min model depth (default is min(thickness,130)) [m]');
-			fielddisplay(self,'zY','strech grid cells bellow top_z by a [top_dz * y ^ (cells bellow top_z)]');
+			fielddisplay(self,'zY','stretch grid cells bellow top_z by a [top_dz * y ^ (cells bellow top_z)]');
 			fielddisplay(self,'InitDensityScaling',{'initial scaling factor multiplying the density of ice','which describes the density of the snowpack.'});
 			fielddisplay(self,'ThermoDeltaTScaling',{'scaling factor to multiply the thermal diffusion timestep (delta t)'});
Index: /issm/trunk-jpl/src/m/classes/SMBgemb.py
===================================================================
--- /issm/trunk-jpl/src/m/classes/SMBgemb.py	(revision 28065)
+++ /issm/trunk-jpl/src/m/classes/SMBgemb.py	(revision 28066)
@@ -105,5 +105,5 @@
         self.dzMin                  = np.nan    # initial min vertical allowable grid spacing (default dzMin/2) [m]
 
-        self.zY                     = np.nan    # strech grid cells bellow top_z by a [top_dz * y ^ (cells bellow top_z)]
+        self.zY                     = np.nan    # stretch grid cells bellow top_z by a [top_dz * y ^ (cells bellow top_z)]
         self.zMax                   = np.nan    # initial max model depth (default is min(thickness, 250)) [m]
         self.zMin                   = np.nan    # initial min model depth (default is min(thickness, 130)) [m]
@@ -191,5 +191,5 @@
         s += '{}\n'.format(fielddisplay(self, 'zMax', 'initial max model depth (default is min(thickness, 500)) [m]'))
         s += '{}\n'.format(fielddisplay(self, 'zMin', 'initial min model depth (default is min(thickness, 30)) [m]'))
-        s += '{}\n'.format(fielddisplay(self, 'zY', 'strech grid cells bellow top_z by a [top_dz * y ^ (cells bellow top_z)]'))
+        s += '{}\n'.format(fielddisplay(self, 'zY', 'stretch grid cells bellow top_z by a [top_dz * y ^ (cells bellow top_z)]'))
         s += '{}\n'.format(fielddisplay(self, 'InitDensityScaling', ['initial scaling factor multiplying the density of ice', 'which describes the density of the snowpack.']))
         s += '{}\n'.format(fielddisplay(self, 'ThermoDeltaTScaling', 'scaling factor to multiply the thermal diffusion timestep (delta t)'))
